@@ -4,6 +4,8 @@
     GIFT, a flexible content based image retrieval system.
     Copyright (C) 1998, 1999, 2000, 2001, 2002, CUI University of Geneva
 
+     Copyright (C) 2003, 2004 Bayreuth University
+      2005 Bamberg University
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -1291,7 +1293,10 @@ void CSessionManager::translate(string inSessionID,
   
   //  assert(lSession);
   if(lFound==mIDToSession.end()){
-    my_throw(VENotFound("Could not find Session"));
+    //my_throw(VENotFound("Could not find Session"));
+    cerr << "Unknown session " << inSessionID << endl;
+    mMutexSessionManager.unlock();
+    return;
   }
   // if this fails this is a real bug
   // it should never happen
